%global         pypi_name    sherpa

Name:           python-sherpa
Version:        4.12.1
Release:        %mkrel 4
Group:          Sciences/Astronomy
Summary:        Sherpa is a modeling and fitting application
License:        AFL
URL:            http://cxc.cfa.harvard.edu/sherpa/
Source0:        https://github.com/sherpa/sherpa/archive/%{version}/%{pypi_name}-%{version}.tar.gz
Patch0:         sherpa-4.11.1-format.patch
#install of group/stk.so is broken, disabling
Patch1:         sherpa-4.11.1-setup.patch
Patch2:         sherpa-4.8.2-arm.patch
# use wcstools and not wcslib
Patch3:         sherpa-4.12.1-wcstools.patch

BuildRequires:  flex
BuildRequires:  bison
BuildRequires:  pkgconfig(cfitsio)
BuildRequires:  fftw-devel
BuildRequires:  gcc-gfortran
BuildRequires:  gcc-c++
BuildRequires:  wcstools-devel


%description
Sherpa is the CIAO modeling and fitting application. It enables the
user to construct complex models from simple definitions and fit those
models to data, using a variety of statistics and optimization method.


%package -n python3-sherpa
Summary:        Python3 implementation of Sherpa
Group:          Development/Python
%{?python_provide:%python_provide python3-%{pypi_name}}
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3-numpy-devel
BuildRequires:  python3-numpy-f2py


%description -n python3-sherpa
Sherpa is the CIAO modeling and fitting application. It enables the
user to construct complex models from simple definitions and fit those
models to data, using a variety of statistics and optimization method.


%prep
%setup -q -n %{pypi_name}-%{version}
%autopatch -p1

sed -i "s|libARCH|%{_lib}|g" setup.cfg
sed -i "s|@python_version@|%{python3_version}|g" setup.cfg

%build
%py3_build

%install
%py3_install

%__rm %{buildroot}%{_bindir}/sherpa_*

%files -n python3-sherpa
%doc LICENSE RELEASE_NOTES CONTRIBUTING.md COPYRIGHT CITATION
#{python3_sitearch}/*.so
%{python3_sitearch}/%{pypi_name}
%{python3_sitearch}/%{pypi_name}-%{version}-*.egg-info


%changelog
* Sat Apr 02 2022 umeabot <umeabot> 4.12.1-4.mga9
+ Revision: 1840924
- Mageia 9 Mass Rebuild

* Mon Feb 21 2022 mrambo3501 <mrambo3501> 4.12.1-3.mga9
+ Revision: 1782622
- rebuild for python-3.10

* Mon Apr 19 2021 daviddavid <daviddavid> 4.12.1-2.mga9
+ Revision: 1717067
- rebuild for python 3.9

* Wed Aug 19 2020 joequant <joequant> 4.12.1-1.mga8
+ Revision: 1615659
- fix wcstool requires
- update to 4.12.1

* Wed Jun 10 2020 joequant <joequant> 4.11.1-3.mga8
+ Revision: 1591554
- fix build
+ pterjan <pterjan>
- Remove usage of obsolete macros (https://github.com/rpm-software-management/rpm/issues/1211)

* Sun Feb 16 2020 umeabot <umeabot> 4.11.1-2.mga8
+ Revision: 1535605
- Mageia 8 Mass Rebuild

* Sun Oct 13 2019 daviddavid <daviddavid> 4.11.1-1.mga8
+ Revision: 1452574
- new version: 4.11.1
- rediff format and setup patches
+ tv <tv>
- rebuild for python-3.8
- drop python2 subpkg

* Thu Jan 10 2019 daviddavid <daviddavid> 4.10.0-4.mga7
+ Revision: 1354122
- rebuild for new Python 3.7

* Sun Sep 09 2018 wally <wally> 4.10.0-3.mga7
+ Revision: 1258040
- fix build on aarch64

* Fri Aug 17 2018 eatdirt <eatdirt> 4.10.0-2.mga7
+ Revision: 1252235
- Fix mess with BR crashing arm build

* Fri Aug 17 2018 eatdirt <eatdirt> 4.10.0-1.mga7
+ Revision: 1252219
- Upgrade to version 4.10.0

* Mon Sep 11 2017 tv <tv> 4.8.2-4.mga7
+ Revision: 1152744
- rebuild for new libgfortran

* Sat Aug 05 2017 pterjan <pterjan> 4.8.2-3.mga7
+ Revision: 1135633
- Rebuild for python 3.6

* Fri Dec 16 2016 eatdirt <eatdirt> 4.8.2-2.mga6
+ Revision: 1075685
- Tentative fix arm build (restoring cephes patch)

* Fri Dec 16 2016 eatdirt <eatdirt> 4.8.2-1.mga6
+ Revision: 1075671
- Upgrade to version 4.8.2

* Sun Jul 31 2016 pterjan <pterjan> 4.5.1-10.mga6
+ Revision: 1044131
- Commit the right patch...
- Try to fix build on arm, no idea how it builds elsewhere

* Sat Feb 20 2016 umeabot <umeabot> 4.5.1-9.mga6
+ Revision: 972174
- Mageia 6 Mass Rebuild

* Thu Oct 29 2015 tv <tv> 4.5.1-8.mga6
+ Revision: 896240
- BR python-numpy-f2py

* Wed Oct 15 2014 umeabot <umeabot> 4.5.1-7.mga5
+ Revision: 748975
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 4.5.1-6.mga5
+ Revision: 729761
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 4.5.1-5.mga5
+ Revision: 688330
- Mageia 5 Mass Rebuild
+ pterjan <pterjan>
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 4.5.1-3.mga4
+ Revision: 544249
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 4.5.1-2.mga4
+ Revision: 499372
- Rebuild to add different pythonegg provides for python 2 and 3

* Sun Aug 04 2013 joequant <joequant> 4.5.1-1.mga4
+ Revision: 463098
- add numpy devel
- imported package python-sherpa

